==> maGUI_2.0.tar.gz: maGUI/R/filter_sp.R <==
filter_sp<-function(h,...){
	f<-function(h,...){
		x<<-svalue(h$obj)
	}
	try(({
		dat2Affy.m<-dat2Affy.m;datAgOne2.m<-datAgOne2.m;datAgTwo2.m<-datAgTwo2.m;datIllBA2.m2<-datIllBA2.m2;
		lumi_NQ.m<-lumi_NQ.m;data.matrix_Nimblegen2.m<-data.matrix_Nimblegen2.m;
		data.matrixNorm.m<-data.matrixNorm.m;data.matrix_onlineNorm.m<-data.matrix_onlineNorm.m;l<-l;tree<-tree;
	}),silent=TRUE)
	platforms=NULL;
	aa=0;bb=0;cc=0;dd=0;ee=0;ff=0;gg=0;hh=0;
	try(({
		if(exists("dat2Affy.m"))aa=length(dat2Affy.m)
		if(exists("datAgOne2.m"))bb=length(datAgOne2.m)
		if(exists("datAgTwo2.m"))cc=length(datAgTwo2.m)
		if(exists("datIllBA2.m2"))dd=length(datIllBA2.m2)
		if(exists("lumi_NQ.m"))ee=length(lumi_NQ.m)
		if(exists("data.matrix_Nimblegen2.m"))ff=length(data.matrix_Nimblegen2.m)
		if(exists("data.matrixNorm.m"))gg=length(data.matrixNorm.m)
		if(exists("data.matrix_onlineNorm.m"))hh=length(data.matrix_onlineNorm.m)
		}),silent=TRUE)
	if(aa!=0)platforms=c(platforms,"Affymetrix")
	if(bb!=0)platforms=c(platforms,"Agilent_OneColor")
	if(cc!=0)platforms=c(platforms,"Agilent_TwoColor")
	if(dd!=0)platforms=c(platforms,"Illumina_Beadarray")
	if(ee!=0)platforms=c(platforms,"Illumina_Lumi")
	if(ff!=0)platforms=c(platforms,"Nimblegen")
	if(gg!=0)platforms=c(platforms,"Series_Matrix")
	if(hh!=0)platforms=c(platforms,"Online_Data")
	print(platforms)

	use.dat2Affy.m=NULL;use.datAgOne2.m=NULL;use.datAgTwo2.m=NULL;use.datIllBA2.m2=NULL;use.lumi_NQ.m=NULL;
	use.data.matrix_Nimblegen2.m=NULL;use.data.matrixNorm.m=NULL;use.data.matrix_onlineNorm.m=NULL;

	rm(use.dat2Affy.m,use.datAgOne2.m,use.datAgTwo2.m,use.datIllBA2.m2,use.lumi_NQ.m,
	use.data.matrix_Nimblegen2.m,use.data.matrixNorm.m,use.data.matrix_onlineNorm.m)
		
	x=NULL
	z=NULL
	sf_xx=NULL

	w_f<-gwindow("Select your data",width=260,height=280,visible=FALSE)
	gp_f<-ggroup(container=w_f,horizontal=FALSE)
	size(gp_f)=c(220,180)
	cbg<-gcheckboxgroup(platforms,container=gp_f,handler=f)
	svalue(cbg,index=FALSE)<-1:8
	gp2_f<-ggroup(container=gp_f,width=30,height=15,horizontal=TRUE)
	addSpring(gp2_f)
	y<-gbutton("CANCEL",border=TRUE,handler=function(h,...){
		dispose(w_f)
		},container=gp2_f,anchor=c(1,-1))
	y2<-gbutton("OK",border=TRUE,handler=function(h,...){
		if(length(x)!=0){
		if(length(which(x=="Affymetrix"))!=0){
			use.dat2Affy.m<<-dat2Affy.m
			filter_sp2(use.dat2Affy.m)
			}
		if(length(which(x=="Agilent_OneColor"))!=0){
			use.datAgOne2.m<<-datAgOne2.m
			filter_sp2(use.datAgOne2.m)
			}
		if(length(which(x=="Agilent_TwoColor"))!=0){
			use.datAgTwo2.m<<-datAgTwo2.m
			filter_sp2(use.datAgTwo2.m)
			}
		if(length(which(x=="Illumina_Beadarray"))!=0){
			use.datIllBA2.m2<<-datIllBA2.m2
			filter_sp2(use.datIllBA2.m2)
			}
		if(length(which(x=="Illumina_Lumi"))!=0){
			use.lumi_NQ.m<<-lumi_NQ.m
			filter_sp2(use.lumi_NQ.m)
			}
		if(length(which(x=="Nimblegen"))!=0){
			use.data.matrix_Nimblegen2.m<<-data.matrix_Nimblegen2.m
			filter_sp2(use.data.matrix_Nimblegen2.m)
			}
		if(length(which(x=="Series_Matrix"))!=0){
			use.data.matrixNorm.m<<-data.matrixNorm.m
			filter_sp2(use.data.matrixNorm.m)
			}
		if(length(which(x=="Online_Data"))!=0){
			use.data.matrix_onlineNorm.m<<-data.matrix_onlineNorm.m
			filter_sp2(use.data.matrix_onlineNorm.m)
			}
		dispose(w_f)
		}else{
			gmessage("Plz select the data for filtering","Select Data")
		}
	},container=gp2_f,anchor=c(1,-1))
	visible(w_f)<-TRUE
	svalue(sb)<-"Done"
}

==> maGUI_2.4.tar.gz: maGUI/R/filter_sp.R <==
filter_sp<-function(h,...){
	f<-function(h,...){
		x<<-svalue(h$obj)
	}
	try(({
		dat2Affy.m<-dat2Affy.m;datAgOne2.m<-datAgOne2.m;datAgTwo2.m<-datAgTwo2.m;datIllBA2.m2<-datIllBA2.m2;
		lumi_NQ.m<-lumi_NQ.m;data.matrix_Nimblegen2.m<-data.matrix_Nimblegen2.m;
		data.matrixNorm.m<-data.matrixNorm.m;data.matrix_onlineNorm.m<-data.matrix_onlineNorm.m;l<-l;tree<-tree;
	}),silent=TRUE)
	platforms=NULL;
	aa=0;bb=0;cc=0;dd=0;ee=0;ff=0;gg=0;hh=0;
	try(({
		if(exists("dat2Affy.m"))aa=length(dat2Affy.m)
		if(exists("datAgOne2.m"))bb=length(datAgOne2.m)
		if(exists("datAgTwo2.m"))cc=length(datAgTwo2.m)
		if(exists("datIllBA2.m2"))dd=length(datIllBA2.m2)
		if(exists("lumi_NQ.m"))ee=length(lumi_NQ.m)
		if(exists("data.matrix_Nimblegen2.m"))ff=length(data.matrix_Nimblegen2.m)
		if(exists("data.matrixNorm.m"))gg=length(data.matrixNorm.m)
		if(exists("data.matrix_onlineNorm.m"))hh=length(data.matrix_onlineNorm.m)
		}),silent=TRUE)
	if(aa!=0)platforms=c(platforms,"Affymetrix")
	if(bb!=0)platforms=c(platforms,"Agilent_OneColor")
	if(cc!=0)platforms=c(platforms,"Agilent_TwoColor")
	if(dd!=0)platforms=c(platforms,"Illumina_Beadarray")
	if(ee!=0)platforms=c(platforms,"Illumina_Lumi")
	if(ff!=0)platforms=c(platforms,"Nimblegen")
	if(gg!=0)platforms=c(platforms,"Series_Matrix")
	if(hh!=0)platforms=c(platforms,"Online_Data")
	print(platforms)

	use.dat2Affy.m=NULL;use.datAgOne2.m=NULL;use.datAgTwo2.m=NULL;use.datIllBA2.m2=NULL;use.lumi_NQ.m=NULL;
	use.data.matrix_Nimblegen2.m=NULL;use.data.matrixNorm.m=NULL;use.data.matrix_onlineNorm.m=NULL;

	rm(use.dat2Affy.m,use.datAgOne2.m,use.datAgTwo2.m,use.datIllBA2.m2,use.lumi_NQ.m,
	use.data.matrix_Nimblegen2.m,use.data.matrixNorm.m,use.data.matrix_onlineNorm.m)
		
	x=NULL
	z=NULL
	sf_xx=NULL

	w_f<-gwindow("Select your data",width=260,height=280,visible=FALSE)
	gp_f<-ggroup(container=w_f,fill="y")
	size(gp_f)=c(220,180)
	cbg<-gcheckboxgroup(platforms,container=gp_f,handler=f)
	svalue(cbg,index=FALSE)<-1:8
	gp2_f<-ggroup(container=gp_f,width=30,height=15,fill="x")
	addSpring(gp2_f)
	y<-gbutton("CANCEL",border=TRUE,handler=function(h,...){
		dispose(w_f)
		},container=gp2_f,anchor=c(1,-1))
	y2<-gbutton("OK",border=TRUE,handler=function(h,...){
		if(length(x)!=0){
		if(length(which(x=="Affymetrix"))!=0){
			use.dat2Affy.m<<-dat2Affy.m
			filter_sp2(use.dat2Affy.m)
			}
		if(length(which(x=="Agilent_OneColor"))!=0){
			use.datAgOne2.m<<-datAgOne2.m
			filter_sp2(use.datAgOne2.m)
			}
		if(length(which(x=="Agilent_TwoColor"))!=0){
			use.datAgTwo2.m<<-datAgTwo2.m
			filter_sp2(use.datAgTwo2.m)
			}
		if(length(which(x=="Illumina_Beadarray"))!=0){
			use.datIllBA2.m2<<-datIllBA2.m2
			filter_sp2(use.datIllBA2.m2)
			}
		if(length(which(x=="Illumina_Lumi"))!=0){
			use.lumi_NQ.m<<-lumi_NQ.m
			filter_sp2(use.lumi_NQ.m)
			}
		if(length(which(x=="Nimblegen"))!=0){
			use.data.matrix_Nimblegen2.m<<-data.matrix_Nimblegen2.m
			filter_sp2(use.data.matrix_Nimblegen2.m)
			}
		if(length(which(x=="Series_Matrix"))!=0){
			use.data.matrixNorm.m<<-data.matrixNorm.m
			filter_sp2(use.data.matrixNorm.m)
			}
		if(length(which(x=="Online_Data"))!=0){
			use.data.matrix_onlineNorm.m<<-data.matrix_onlineNorm.m
			filter_sp2(use.data.matrix_onlineNorm.m)
			}
		dispose(w_f)
		}else{
			gmessage("Plz select the data for filtering","Select Data")
		}
	},container=gp2_f,anchor=c(1,-1))
	visible(w_f)<-TRUE
	svalue(sb)<-"Done"
}
